CCL: /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_lsst_specs.h Source File

CCL

ccl_lsst_specs.h
Go to the documentation of this file.
1
3 #pragma once
4 #include "ccl_core.h"
5 #include "math.h"
6 #include "gsl/gsl_integration.h"
7 #include "gsl/gsl_spline.h"
8
14 typedef struct {
15 double (* your_pz_func)(double, double, void *, int*); /*< Function returns the liklihood of measuring a z_ph
16 * (first double) given a z_spec (second double), with a pointer to additonal arguments and a status flag.*/
17 void * your_pz_params; /*< Additional parameters to be passed into your_pz_func */
18 } user_pz_info;
19
29 double ccl_specs_bias_clustering(ccl_cosmology * cosmo, double a, int * status);
30
43 void ccl_specs_dNdz_tomog(double z, int dNdz_type, double bin_zmin, double bin_zmax, user_pz_info * user_info, double *tomoout, int *status);
44
51 user_pz_info* ccl_specs_create_photoz_info(void * user_params, double(*user_pz_func)(double, double,void*,int*));
52
57 void ccl_specs_free_photoz_info(user_pz_info *my_photoz_info);
58
65 double ccl_specs_sigmaz_clustering(double z);
66
73 double ccl_specs_sigmaz_sources(double z);
74
75 // Specifying the dNdz
76 // lensing (Chang et al 2013)
77 #define DNDZ_WL_CONS 1 //k=0.5
78 #define DNDZ_WL_FID 2 //k=1
79 #define DNDZ_WL_OPT 3 //k=2
80 // Clustering
81 #define DNDZ_NC 4
82
83 //LSST redshift range for lensing sources
84 #define Z_MIN_SOURCES 0.1
85 #define Z_MAX_SOURCES 3.0
86
user_pz_info::your_pz_params
void * your_pz_params
Definition: ccl_lsst_specs.h:17
ccl_core.h
ccl_specs_free_photoz_info
void ccl_specs_free_photoz_info(user_pz_info *my_photoz_info)
Definition: ccl_lsst_specs.c:129
user_pz_info
Definition: ccl_lsst_specs.h:14
ccl_specs_create_photoz_info
user_pz_info * ccl_specs_create_photoz_info(void *user_params, double(*user_pz_func)(double, double, void *, int *))
Definition: ccl_lsst_specs.c:115
ccl_specs_bias_clustering
double ccl_specs_bias_clustering(ccl_cosmology *cosmo, double a, int *status)
Definition: ccl_lsst_specs.c:56
ccl_specs_sigmaz_sources
double ccl_specs_sigmaz_sources(double z)
Definition: ccl_lsst_specs.c:45
ccl_specs_sigmaz_clustering
double ccl_specs_sigmaz_clustering(double z)
Definition: ccl_lsst_specs.c:35
ccl_cosmology
Definition: ccl_core.h:115
ccl_specs_dNdz_tomog
void ccl_specs_dNdz_tomog(double z, int dNdz_type, double bin_zmin, double bin_zmax, user_pz_info *user_info, double *tomoout, int *status)
Definition: ccl_lsst_specs.c:227